@@ -116,13 +116,13 @@ class TestJobLock(unittest.TestCase, contextlib.ExitStack):
       self.assertTrue(lock6)
 
   def testJobLockAndWait(self):
-    with JobLockAndWait(self.tmpdir/"lock1.lock", 0.001) as lock1:
+    with JobLockAndWait(self.tmpdir/"lock1.lock", 0.001, silent=True) as lock1:
       self.assertEqual(lock1.niterations, 1)
 
     with open(self.tmpdir/"lock2.lock", "w") as f:
       f.write("SLURM 0 1234567")
     with self.assertRaises(RuntimeError):
-      with JobLockAndWait(self.tmpdir/"lock2.lock", 0.001, maxiterations=10) as lock2:
+      with JobLockAndWait(self.tmpdir/"lock2.lock", 0.001, maxiterations=10, silent=True) as lock2:
         pass
 
     dummysqueue = """
@@ -137,7 +137,7 @@ class TestJobLock(unittest.TestCase, contextlib.ExitStack):
     (self.tmpdir/"squeue").chmod(0o0777)
     os.environ["PATH"] = f"{self.tmpdir}:"+os.environ["PATH"]
 
-    with JobLockAndWait(self.tmpdir/"lock2.lock", 0.001, maxiterations=10) as lock2:
+    with JobLockAndWait(self.tmpdir/"lock2.lock", 0.001, maxiterations=10, silent=True) as lock2:
       self.assertEqual(lock2.niterations, 2)
 
   def testCorruptFileTimeout(self):
@@ -170,18 +170,18 @@ class TestJobLock(unittest.TestCase, contextlib.ExitStack):
     with open(self.tmpdir/"lock1.lock_30", "w"): pass
     time.sleep(1)
     with open(self.tmpdir/"lock1.lock_10", "w"): pass
-    clean_up_old_job_locks(self.tmpdir, howold=datetime.timedelta(seconds=1), dryrun=True)
+    clean_up_old_job_locks(self.tmpdir, howold=datetime.timedelta(seconds=1), dryrun=True, silent=True)
     self.assertTrue((self.tmpdir/"lock1.lock_2").exists())
     self.assertTrue((self.tmpdir/"lock1.lock_5").exists())
     self.assertTrue((self.tmpdir/"lock1.lock_10").exists())
     self.assertTrue((self.tmpdir/"lock1.lock_30").exists())
     time.sleep(1)
-    clean_up_old_job_locks(self.tmpdir, howold=datetime.timedelta(seconds=1), dryrun=True)
+    clean_up_old_job_locks(self.tmpdir, howold=datetime.timedelta(seconds=1), dryrun=True, silent=True)
     self.assertTrue((self.tmpdir/"lock1.lock_2").exists())
     self.assertTrue((self.tmpdir/"lock1.lock_5").exists())
     self.assertTrue((self.tmpdir/"lock1.lock_10").exists())
     self.assertTrue((self.tmpdir/"lock1.lock_30").exists())
-    clean_up_old_job_locks(self.tmpdir, howold=datetime.timedelta(seconds=1))
+    clean_up_old_job_locks(self.tmpdir, howold=datetime.timedelta(seconds=1), silent=True)
     self.assertFalse((self.tmpdir/"lock1.lock_2").exists())
     self.assertFalse((self.tmpdir/"lock1.lock_5").exists())
     self.assertFalse((self.tmpdir/"lock1.lock_10").exists())
